@@ -1,6 +1,6 @@
 from django.contrib import admin
 
-from .models import S3File
+from .s3filesmanager.models import S3File
 
 
 class S3FileAdmin(admin.ModelAdmin):
